@@ -19,10 +19,6 @@ L<Net::RDAP::Object> represents such objects, whether top-level or
 embedded. It inherits from L<Net::RDAP::Base> so has all the methods
 available to that module.
 
-When L<Net::RDAP::Object> objects are instantiated by L<Net::RDAP>
-from RDAP server responses, a C<self> link will be added to the
-object, if it doesn't already have one.
-
 =cut
 
 #
@@ -34,15 +30,6 @@ sub new {
 
 	my $self = $package->SUPER::new($args);
 
-	# try to make sure that this object always has a "self" URL:
-	if ($url && !$self->self) {
-		push(@{$self->{'links'}}, {
-			'rel'	=> 'self',
-			'href'	=> $url->as_string,
-			'type'	=> 'application/rdap+json',
-		});
-	}
-
 	return $self;
 }
 
